@@ -7,8 +7,8 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.selectors import is_instance
-from cubicweb.web.views import baseviews
+from cubicweb.predicates import is_instance
+from cubicweb.view import EntityView
 from cubicweb.web.views.plots import FlotPlotWidget
 
 def cumsum(data):
@@ -42,7 +42,7 @@ def cumsum(data):
 #         trend.append( (eta, 0) )
 #     return trend
 
-class TicketBurndownView(baseviews.EntityView):
+class TicketBurndownView(EntityView):
     __regid__ = "burndown_chart"
     __select__ = is_instance('Ticket')
     title = _('burn down chart')
